@@ -91,6 +91,8 @@ public:
      */
     void focusNextTab();
 
+    /** BEGIN Location History Stuff **/
+
     /**
      * go forward in location history
      */
@@ -111,6 +113,13 @@ public:
      */
     bool isHistoryForwardEnabled() const;
 
+    /**
+     * Add a jump location for jumping back and forth between history
+     */
+    void addPositionToHistory(const QUrl &url, KTextEditor::Cursor, bool calledExternally = false);
+
+    /** END Location History Stuff **/
+
 public Q_SLOTS:
     void documentDestroyed(QObject *doc);
     void updateDocumentName(KTextEditor::Document *doc);
@@ -156,11 +165,6 @@ private:
      */
     int hiddenDocuments() const;
 
-    /**
-     * Add a jump location for jumping back and forth between history
-     */
-    void addJump(const QUrl &url, KTextEditor::Cursor);
-
 private:
     // Kate's view manager
     KateViewManager *m_viewManager;
